.. _module_ext_datagen:

DataGen
=======

This section contains module documentation of DataGen extension.

.. toctree::
   :maxdepth: 1
   
   main
   jsongen
   xmlgen
   asn1codec
   serializer
   selenium